%
% Script file ratetest.m
%
% Demonstration of Matlab interaction with ADMXRC card
%
% Simple test of data transfer speeds in Slave mode using
% Programmed I/O and DMA

% Initialise card 
handle=admxrc_init([],1);
% Load bit file onto card
fname=getFPGAfilename(handle,'zbt');

[id,sn,bt,ft]=admxrc_getinfo(handle);
admxrc_setclockrate(handle,0,33);

admxrc_config(handle,fname);

if (strcmp(bt,'xrc2'))
  admxrc_setclockrate(handle,0,66);
else
  admxrc_setclockrate(handle,0,33);
end 
admxrc_setclockrate(handle,1,40);
pause(2);

fprintf(1,'Size reg = %8.8x\n',double(admxrc_read32(handle,8,1)));
fprintf(1,'Info reg = %8.8x\n',double(admxrc_read32(handle,16,1)));
fprintf(1,'Status reg = %8.8x\n',double(admxrc_read32(handle,20,1)));

if (strcmp(bt,'xrc2'))
  admxrc_write32(handle,4,int32(1));
else
  admxrc_write32(handle,4,int32(0));
end 




N=65536*4;
offset=2097152;
d=int32(1:N);
disp('Starting Programmed I/O Writes');
tic
for k=1:10
admxrc_write32(handle,offset,d);
end
tpw=toc;
disp('Starting Programmed I/O Reads');
tic
for k=1:10
out=admxrc_read32(handle,offset,N); 
end
tpr=toc;

disp('Starting DMA Writes');
tic
for k=1:10
admxrc_write32_dma(handle,offset,d);
end
tdw=toc;


disp('Starting DMA Reads');
tic
for k=1:10
out=admxrc_read32_dma(handle,offset,N);
end
tdr=toc;

disp('Data Rates');
fprintf(1,'Programmed I/O Write to FPGA %f Mb/s\n',4*10*N/tpw/(1024*1024));
fprintf(1,'Prorgammed I/O Read from FPGA %f Mb/s\n',4*10*N/tpr/(1024*1024));
fprintf(1,'DMA Write to FPGA %f Mb/s\n',4*10*N/tdw/(1024*1024));
fprintf(1,'DMA Read from FPGA %f Mb/s\n',4*10*N/tdr/(1024*1024));



% Close card
admxrc_close(handle);
  
